@@ -173,6 +173,31 @@ impl FontSettingList {
     }
 }
 
+#[repr(u8)]
+#[derive(Copy, Clone, PartialEq, Debug, Default)]
+pub enum UnderlineShape {
+    #[default]
+    Regular = 0,
+    Dotted = 1,
+    Dashed = 2,
+    Curly = 3,
+}
+
+#[derive(Copy, Clone, PartialEq, Debug)]
+pub struct UnderlineInfo {
+    pub offset: f32,
+    pub size: f32,
+    pub is_doubled: bool,
+    pub shape: UnderlineShape,
+}
+
+#[derive(Copy, Clone, PartialEq, Debug)]
+pub enum FragmentStyleDecoration {
+    // offset, size
+    Underline(UnderlineInfo),
+    Strikethrough,
+}
+
 #[derive(Copy, Clone, PartialEq, Debug)]
 pub struct FragmentStyle {
     /// Internal identifier for a list of font families and attributes.
@@ -196,23 +221,16 @@ pub struct FragmentStyle {
     /// Multiplicative line spacing factor.
     pub line_spacing: f32,
     /// Enable underline decoration.
-    pub underline: bool,
-    /// Offset of an underline.
-    pub underline_offset: Option<f32>,
-    /// Color of an underline.
-    pub underline_color: Option<[f32; 4]>,
-    /// Thickness of an underline.
-    pub underline_size: Option<f32>,
-    /// Cursor
+    pub decoration: Option<FragmentStyleDecoration>,
+    /// Decoration color.
+    pub decoration_color: Option<[f32; 4]>,
+    /// Cursor style.
     pub cursor: SugarCursor,
 }
 
 impl Default for FragmentStyle {
     fn default() -> Self {
         Self {
-            // dir: Direction::LeftToRight,
-            // dir_changed: false,
-            // lang: None,
             font: 0,
             width: 1.0,
             font_attrs: (Stretch::NORMAL, Weight::NORMAL, Style::Normal),
@@ -224,10 +242,8 @@ impl Default for FragmentStyle {
             color: [1.0, 1.0, 1.0, 1.0],
             background_color: None,
             cursor: SugarCursor::Disabled,
-            underline: false,
-            underline_offset: None,
-            underline_color: None,
-            underline_size: None,
+            decoration: None,
+            decoration_color: None,
         }
     }
 }
@@ -246,10 +262,8 @@ impl FragmentStyle {
             color: [1.0, 1.0, 1.0, 1.0],
             background_color: None,
             cursor: SugarCursor::Disabled,
-            underline: false,
-            underline_offset: None,
-            underline_color: None,
-            underline_size: None,
+            decoration: None,
+            decoration_color: None,
         }
     }
 }
@@ -269,16 +283,20 @@ impl From<&Sugar> for FragmentStyle {
             SugarStyle::Italic => {
                 style.font_attrs.2 = Style::Italic;
             }
-            _ => {}
+            SugarStyle::Disabled => {}
         }
 
         let mut has_underline_cursor = false;
         match sugar.cursor {
             SugarCursor::Underline(cursor_color) => {
-                style.underline = true;
-                style.underline_offset = Some(-1.);
-                style.underline_color = Some(cursor_color);
-                style.underline_size = Some(-1.);
+                style.decoration =
+                    Some(FragmentStyleDecoration::Underline(UnderlineInfo {
+                        offset: -1.0,
+                        size: -1.0,
+                        is_doubled: false,
+                        shape: UnderlineShape::Regular,
+                    }));
+                style.decoration_color = Some(cursor_color);
 
                 has_underline_cursor = true;
             }
@@ -288,27 +306,68 @@ impl From<&Sugar> for FragmentStyle {
             SugarCursor::Caret(cursor_color) => {
                 style.cursor = SugarCursor::Caret(cursor_color);
             }
-            _ => {}
+            SugarCursor::Disabled => {}
         }
 
         match &sugar.decoration {
             SugarDecoration::Underline => {
                 if !has_underline_cursor {
-                    style.underline = true;
-                    style.underline_offset = Some(-2.);
-                    style.underline_size = Some(1.);
+                    style.decoration =
+                        Some(FragmentStyleDecoration::Underline(UnderlineInfo {
+                            offset: -2.0,
+                            size: 2.0,
+                            is_doubled: false,
+                            shape: UnderlineShape::Regular,
+                        }));
                 }
             }
             SugarDecoration::Strikethrough => {
-                style.underline = true;
-                style.underline_offset = Some(style.font_size / 2.);
-                style.underline_size = Some(2.);
+                style.decoration = Some(FragmentStyleDecoration::Strikethrough);
             }
-            _ => {}
+            SugarDecoration::DoubleUnderline => {
+                style.decoration =
+                    Some(FragmentStyleDecoration::Underline(UnderlineInfo {
+                        offset: -4.0,
+                        size: 1.0,
+                        is_doubled: true,
+                        shape: UnderlineShape::Regular,
+                    }));
+            }
+            SugarDecoration::DottedUnderline => {
+                style.decoration =
+                    Some(FragmentStyleDecoration::Underline(UnderlineInfo {
+                        offset: -2.0,
+                        size: 2.0,
+                        is_doubled: false,
+                        shape: UnderlineShape::Dotted,
+                    }));
+            }
+            SugarDecoration::DashedUnderline => {
+                style.decoration =
+                    Some(FragmentStyleDecoration::Underline(UnderlineInfo {
+                        offset: -2.0,
+                        size: 2.0,
+                        is_doubled: false,
+                        shape: UnderlineShape::Dashed,
+                    }));
+            }
+            SugarDecoration::CurlyUnderline => {
+                style.decoration =
+                    Some(FragmentStyleDecoration::Underline(UnderlineInfo {
+                        offset: -2.0,
+                        size: 1.0,
+                        is_doubled: false,
+                        shape: UnderlineShape::Curly,
+                    }));
+            }
+            SugarDecoration::Disabled => {}
         }
 
         style.color = sugar.foreground_color;
         style.background_color = sugar.background_color;
+        if let Some(decoration_color) = sugar.decoration_color {
+            style.decoration_color = Some(decoration_color);
+        }
 
         style
     }
